py4j.model (py4j-java 0.10.9.7 API)

# Package py4j.model

- Class Summary
  Class | Description
  --- | ---
  HelpPageGenerator | The HelpPageGenerator generates a help page (a String) for a class or a method.
  Py4JClass | Model of a Java class used to create a help page.
  Py4JField | Model of a Java field used to create a help page.
  Py4JMember | Model of a Java member (class, method, or field) used to create a help page.
  Py4JMethod | Model of a Java method used to create a help page.